"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QInputMethodEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qinputmethodevent.html

    **Detailed Description**

    Input method events are sent to widgets when an input method is used to
    enter text into a widget. Input methods are widely used to enter text for
    languages with non-Latin alphabets.

    Note that when creating custom text editing widgets, the
    **Qt::WA_InputMethodEnabled**  window attribute must be set explicitly
    (using the **QWidget::setAttribute** () function) in order to receive input
    method events.

    The events are of interest to authors of keyboard entry widgets who want to
    be able to correctly handle languages with complex character input. Text
    input in such languages is usually a three step process:

    1.  **Starting to Compose**

    When the user presses the first key on a
    keyboard, an input context is created. This input context will contain a
    string of the typed characters.

      2. **Composing**

    With every new key
    pressed, the input method will try to create a matching string for the text
    typed so far called preedit string. While the input context is active, the
    user can only move the cursor inside the string belonging to this input
    context.

      3. **Completing**

    At some point, the user will activate a user
    interface component (perhaps using a particular key) where they can choose
    from a number of strings matching the text they have typed so far. The user
    can either confirm their choice cancel the input; in either case the input
    context will be closed.

    QInputMethodEvent models these three stages, and transfers the information
    needed to correctly render the intermediate result. A QInputMethodEvent has
    two main parameters: **preeditString** () and **commitString** (). The
    **preeditString** () parameter gives the currently active preedit string.
    The **commitString** () parameter gives a text that should get added to (or
    replace parts of) the text of the editor widget. It usually is a result of
    the input operations and has to be inserted to the widgets text directly
    before the preedit string.

    If the **commitString** () should replace parts of the of the text in the
    editor, **replacementLength** () will contain the number of characters to be
    replaced. **replacementStart** () contains the position at which characters
    are to be replaced relative from the start of the preedit string.

    A number of attributes control the visual appearance of the preedit string
    (the visual appearance of text outside the preedit string is controlled by
    the widget only). The **AttributeType**  enum describes the different
    attributes that can be set.

    A class implementing **QWidget::inputMethodEvent** () or
    **QGraphicsItem::inputMethodEvent** () should at least understand and honor
    the **TextFormat**  and **Cursor**  attributes.

    Since input methods need to be able to query certain properties from the
    widget or graphics item, subclasses must also implement
    **QWidget::inputMethodQuery** () and **QGraphicsItem::inputMethodQuery** (),
    respectively.

    When receiving an input method event, the text widget has to performs the
    following steps:

    1. If the widget has selected text, the selected text should get removed.
    2. Remove the text starting at **replacementStart** () with length
    **replacementLength** () and replace it by the **commitString** (). If
    **replacementLength** () is 0, **replacementStart** () gives the insertion
    position for the **commitString** ().

    When doing replacement the area of
    the preedit string is ignored, thus a replacement starting at -1 with a
    length of 2 will remove the last character before the preedit string and the
    first character afterwards, and insert the commit string directly before the
    preedit string.

    If the widget implements undo/redo, this operation gets
    added to the undo stack.

      3. If there is no current preedit string, insert
    the **preeditString** () at the current cursor position; otherwise replace
    the previous **preeditString**  with the one received from this event.

    If
    the widget implements undo/redo, the **preeditString** () should not
    influence the undo/redo stack in any way.

    The widget should examine the
    list of attributes to apply to the preedit string. It has to understand at
    least the **TextFormat**  and Cursor attributes and render them as
    specified.

    **See also** **QInputMethod** .
    """

    class AttributeType(enum.Enum):
        TextFormat: QInputMethodEvent = ...
        Cursor: QInputMethodEvent = ...
        Language: QInputMethodEvent = ...
        Ruby: QInputMethodEvent = ...
        Selection: QInputMethodEvent = ...

    class Attribute(PyQt6.sip.simplewrapper):
        length: int = ...
        start: int = ...
        type = ...
        value: typing = ...

        @typing.overload
        def __init__(
            self, t: "QInputMethodEvent.AttributeType", s: int, l: int, val: typing.Any
        ) -> None:
            ...

        @typing.overload
        def __init__(
            self, typ: "QInputMethodEvent.AttributeType", s: int, l: int
        ) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QInputMethodEvent.Attribute") -> None:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#QInputMethodEvent-2

        **QInputMethodEvent::QInputMethodEvent()**

        Constructs an event of type **QEvent::InputMethod** . The **attributes**
        (), **preeditString** (), **commitString** (), **replacementStart** (),
        and **replacementLength** () are initialized to default values.

        **See also** **setCommitString** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        preeditText: str,
        attributes: typing.Iterable["QInputMethodEvent.Attribute"],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#QInputMethodEvent-3

        **QInputMethodEvent::QInputMethodEvent(const QString & preeditText ,
        const QList<QInputMethodEvent::Attribute> & attributes )**

        Constructs an event of type **QEvent::InputMethod** . The preedit text
        is set to **preeditText** , the attributes to **attributes**.

        The **commitString** (), **replacementStart** (), and
        **replacementLength** () values can be set using **setCommitString** ().

        **See also** **preeditString** () and **attributes** ().
        """
        ...

    def clone(self) -> "QInputMethodEvent":
        ...

    def replacementLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#replacementLength

        **int QInputMethodEvent::replacementLength() const**

        Returns the number of characters to be replaced in the preedit string.

        **See also** **replacementStart** () and **setCommitString** ().
        """
        ...

    def replacementStart(self) -> int:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#replacementStart

        **int QInputMethodEvent::replacementStart() const**

        Returns the position at which characters are to be replaced relative
        from the start of the preedit string.

        **See also** **replacementLength** () and **setCommitString** ().
        """
        ...

    def commitString(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#commitString

        **const QString &QInputMethodEvent::commitString() const**

        Returns the text that should get added to (or replace parts of) the text
        of the editor widget. It usually is a result of the input operations and
        has to be inserted to the widgets text directly before the preedit
        string.

        **See also** **setCommitString** (), **preeditString** (),
        **replacementStart** (), and **replacementLength** ().
        """
        ...

    def preeditString(self) -> str:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#preeditString

        **const QString &QInputMethodEvent::preeditString() const**

        Returns the preedit text, i.e. the text before the user started editing
        it.

        **See also** **commitString** () and **attributes** ().
        """
        ...

    def attributes(self) -> typing.List["QInputMethodEvent.Attribute"]:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#attributes

        **const QList<QInputMethodEvent::Attribute>
        &QInputMethodEvent::attributes() const**

        Returns the list of attributes passed to the **QInputMethodEvent**
        constructor. The attributes control the visual appearance of the preedit
        string (the visual appearance of text outside the preedit string is
        controlled by the widget only).

        **See also** **preeditString** () and **Attribute** .
        """
        ...

    def setCommitString(
        self, commitString: str, from_: int = ..., length: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qinputmethodevent.html#setCommitString

        **void QInputMethodEvent::setCommitString(const QString & commitString ,
        int replaceFrom = 0, int replaceLength = 0)**

        Sets the commit string to **commitString**.

        The commit string is the text that should get added to (or replace parts
        of) the text of the editor widget. It usually is a result of the input
        operations and has to be inserted to the widgets text directly before
        the preedit string.

        If the commit string should replace parts of the of the text in the
        editor, **replaceLength** specifies the number of characters to be
        replaced. **replaceFrom** specifies the position at which characters are
        to be replaced relative from the start of the preedit string.

        **See also** **commitString** (), **replacementStart** (), and
        **replacementLength** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QItemSelectionModel(QObject):
    """
    https://doc.qt.io/qt-6/qitemselectionmodel.html

    **Detailed Description**

    A QItemSelectionModel keeps track of the selected items in a view, or in
    several views onto the same model. It also keeps track of the currently
    selected item in a view.

    The QItemSelectionModel class is one of the **Model/View Classes**  and is
    part of Qt's **model/view framework** .

    The selected items are stored using ranges. Whenever you want to modify the
    selected items use **select** () and provide either a **QItemSelection** ,
    or a **QModelIndex**  and a **QItemSelectionModel::SelectionFlag** .

    The QItemSelectionModel takes a two layer approach to selection management,
    dealing with both selected items that have been committed and items that are
    part of the current selection. The current selected items are part of the
    current interactive selection (for example with rubber-band selection or
    keyboard-shift selections).

    To update the currently selected items, use the bitwise OR of
    **QItemSelectionModel::Current**  and any of the other **SelectionFlags** .
    If you omit the **QItemSelectionModel::Current**  command, a new current
    selection will be created, and the previous one added to the whole
    selection. All functions operate on both layers; for example,
    **selecteditems** () will return items from both layers.

    **Note:** Since 5.5, **model** , **hasSelection** , and **currentIndex**
    are meta-object properties.

    **See also** **Model/View Programming** , **QAbstractItemModel** , and
    **Chart Example** .
    """

    class SelectionFlag(enum.Flag):
        NoUpdate: QItemSelectionModel = ...
        Clear: QItemSelectionModel = ...
        Select: QItemSelectionModel = ...
        Deselect: QItemSelectionModel = ...
        Toggle: QItemSelectionModel = ...
        Current: QItemSelectionModel = ...
        Rows: QItemSelectionModel = ...
        Columns: QItemSelectionModel = ...
        SelectCurrent: QItemSelectionModel = ...
        ToggleCurrent: QItemSelectionModel = ...
        ClearAndSelect: QItemSelectionModel = ...

    @typing.overload
    def __init__(self, model: typing.Optional[QAbstractItemModel] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#QItemSelectionModel

        **QItemSelectionModel::QItemSelectionModel(QAbstractItemModel * model =
        nullptr)**

        Constructs a selection model that operates on the specified item
        **model**.
        """
        ...

    @typing.overload
    def __init__(self, model: QAbstractItemModel, parent: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#QItemSelectionModel-1

        **QItemSelectionModel::QItemSelectionModel(QAbstractItemModel * model ,
        QObject * parent )**

        Constructs a selection model that operates on the specified item
        **model** with **parent**.
        """
        ...

    def setModel(self, model: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#setModel

        **[since 5.5] void QItemSelectionModel::setModel(QAbstractItemModel *
        model )**

        Sets the model to **model**. The **modelChanged** () signal will be
        emitted.

        This function was introduced in Qt 5.5.

        **See also** **model** () and **modelChanged** ().
        """
        ...

    def selectedColumns(self, row: int = ...) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#selectedColumns

        **[invokable] QModelIndexList QItemSelectionModel::selectedColumns(int
        row = 0) const**

        Returns the indexes in the given **row** for columns where all rows are
        selected.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **selectedIndexes** () and **selectedRows** ().
        """
        ...

    def selectedRows(self, column: int = ...) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#selectedRows

        **[invokable] QModelIndexList QItemSelectionModel::selectedRows(int
        column = 0) const**

        Returns the indexes in the given **column** for the rows where all
        columns are selected.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **selectedIndexes** () and **selectedColumns** ().
        """
        ...

    def hasSelection(self) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#hasSelection

        **bool QItemSelectionModel::hasSelection() const**

        Returns `true` if the selection model contains any selected item,
        otherwise returns `false`.
        """
        ...

    def emitSelectionChanged(
        self, newSelection: "QItemSelection", oldSelection: "QItemSelection"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#emitSelectionChanged

        **[protected] void QItemSelectionModel::emitSelectionChanged(const
        QItemSelection & newSelection , const QItemSelection & oldSelection )**

        Compares the two selections **newSelection** and **oldSelection** and
        emits **selectionChanged** () with the deselected and selected items.
        """
        ...

    def clearCurrentIndex(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#clearCurrentIndex

        **[virtual slot] void QItemSelectionModel::clearCurrentIndex()**

        Clears the current index. Emits **currentChanged** ().
        """
        ...

    def setCurrentIndex(
        self, index: QModelIndex, command: "QItemSelectionModel.SelectionFlag"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#setCurrentIndex

        **[virtual slot] void QItemSelectionModel::setCurrentIndex(const
        QModelIndex & index , QItemSelectionModel::SelectionFlags command )**

        Sets the model item **index** to be the current item, and emits
        **currentChanged** (). The current item is used for keyboard navigation
        and focus indication; it is independent of any selected items, although
        a selected item can also be the current item.

        Depending on the specified **command** , the **index** can also become
        part of the current selection.

        **See also** **currentIndex** () and **select** ().
        """
        ...

    @typing.overload
    def select(
        self, index: QModelIndex, command: "QItemSelectionModel.SelectionFlag"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#select

        **[virtual slot] void QItemSelectionModel::select(const QModelIndex &
        index , QItemSelectionModel::SelectionFlags command )**

        Selects the model item **index** using the specified **command** , and
        emits **selectionChanged** ().

        **See also** **QItemSelectionModel::SelectionFlags** .
        """
        ...

    @typing.overload
    def select(
        self, selection: "QItemSelection", command: "QItemSelectionModel.SelectionFlag"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#select-1

        **[virtual slot] void QItemSelectionModel::select(const QItemSelection &
        selection , QItemSelectionModel::SelectionFlags command )**

        Selects the item **selection** using the specified **command** , and
        emits **selectionChanged** ().

        **See also** **QItemSelectionModel::SelectionFlag** .
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#reset

        **[virtual slot] void QItemSelectionModel::reset()**

        Clears the selection model. Does not emit any signals.
        """
        ...

    def clearSelection(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#clearSelection

        **[slot] void QItemSelectionModel::clearSelection()**

        Clears the selection in the selection model. Emits **selectionChanged**
        ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#clear

        **[virtual slot] void QItemSelectionModel::clear()**

        Clears the selection model. Emits **selectionChanged** () and
        **currentChanged** ().
        """
        ...

    def model(self) -> QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#model

        **const QAbstractItemModel *QItemSelectionModel::model() const**

        Returns the item model operated on by the selection model.

        **See also** **setModel** ().
        """
        ...

    def selection(self) -> "QItemSelection":
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#selection

        **const QItemSelection QItemSelectionModel::selection() const**

        Returns the selection ranges stored in the selection model.
        """
        ...

    def selectedIndexes(self) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#selectedIndexes

        **QModelIndexList QItemSelectionModel::selectedIndexes() const**

        Returns a list of all selected model item indexes. The list contains no
        duplicates, and is not sorted.

        **Note:** Getter function for property selectedIndexes.
        """
        ...

    def columnIntersectsSelection(self, column: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#columnIntersectsSelectio
        n

        **[invokable] bool QItemSelectionModel::columnIntersectsSelection(int
        column , const QModelIndex & parent = QModelIndex()) const**

        Returns `true` if there are any items selected in the **column** with
        the given **parent**.

        **Note:** Since Qt 5.15, the default argument for **parent** is an empty
        model index.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def rowIntersectsSelection(self, row: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#rowIntersectsSelection

        **[invokable] bool QItemSelectionModel::rowIntersectsSelection(int row ,
        const QModelIndex & parent = QModelIndex()) const**

        Returns `true` if there are any items selected in the **row** with the
        given **parent**.

        **Note:** Since Qt 5.15, the default argument for **parent** is an empty
        model index.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def isColumnSelected(self, column: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#isColumnSelected

        **[invokable] bool QItemSelectionModel::isColumnSelected(int column ,
        const QModelIndex & parent = QModelIndex()) const**

        Returns `true` if all items are selected in the **column** with the
        given **parent**.

        Note that this function is usually faster than calling **isSelected** ()
        on all items in the same column and that unselectable items are ignored.

        **Note:** Since Qt 5.15, the default argument for **parent** is an empty
        model index.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def isRowSelected(self, row: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#isRowSelected

        **[invokable] bool QItemSelectionModel::isRowSelected(int row , const
        QModelIndex & parent = QModelIndex()) const**

        Returns `true` if all items are selected in the **row** with the given
        **parent**.

        Note that this function is usually faster than calling **isSelected** ()
        on all items in the same row and that unselectable items are ignored.

        **Note:** Since Qt 5.15, the default argument for **parent** is an empty
        model index.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def isSelected(self, index: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#isSelected

        **[invokable] bool QItemSelectionModel::isSelected(const QModelIndex &
        index ) const**

        Returns `true` if the given model item **index** is selected.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def currentIndex(self) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#currentIndex

        **QModelIndex QItemSelectionModel::currentIndex() const**

        Returns the model item index for the current item, or an invalid index
        if there is no current item.

        **See also** **setCurrentIndex** ().
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#currentChanged

        **[signal] void QItemSelectionModel::currentChanged(const QModelIndex &
        current , const QModelIndex & previous )**

        This signal is emitted whenever the current item changes. The
        **previous** model item index is replaced by the **current** index as
        the selection's current item.

        Note that this signal will not be emitted when the item model is reset.

        **See also** **currentIndex** (), **setCurrentIndex** (), and
        **selectionChanged** ().
        """
        ...

    @property
    def currentColumnChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#currentColumnChanged

        **[signal] void QItemSelectionModel::currentColumnChanged(const
        QModelIndex & current , const QModelIndex & previous )**

        This signal is emitted if the **current** item changes and its column is
        different to the column of the **previous** current item.

        Note that this signal will not be emitted when the item model is reset.

        **See also** **currentChanged** (), **currentRowChanged** (),
        **currentIndex** (), and **setCurrentIndex** ().
        """
        ...

    @property
    def currentRowChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#currentRowChanged

        **[signal] void QItemSelectionModel::currentRowChanged(const QModelIndex
        & current , const QModelIndex & previous )**

        This signal is emitted if the **current** item changes and its row is
        different to the row of the **previous** current item.

        Note that this signal will not be emitted when the item model is reset.

        **See also** **currentChanged** (), **currentColumnChanged** (),
        **currentIndex** (), and **setCurrentIndex** ().
        """
        ...

    @property
    def modelChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#modelChanged

        **[signal, since 5.5] void
        QItemSelectionModel::modelChanged(QAbstractItemModel * model )**

        This signal is emitted when the **model** is successfully set with
        **setModel** ().

        This function was introduced in Qt 5.5.

        **See also** **model** () and **setModel** ().
        """
        ...

    @property
    def selectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qitemselectionmodel.html#selectionChanged

        **[signal] void QItemSelectionModel::selectionChanged(const
        QItemSelection & selected , const QItemSelection & deselected )**

        This signal is emitted whenever the selection changes. The change in the
        selection is represented as an item selection of **deselected** items
        and an item selection of **selected** items.

        Note the that the current index changes independently from the
        selection. Also note that this signal will not be emitted when the item
        model is reset.

        Items which stay selected but change their index are not included in
        **selected** and **deselected**. Thus, this signal might be emitted with
        both **selected** and **deselected** empty, if only the indices of
        selected items change.

        **Note:** Notifier signal for property **selectedIndexes** .

        **See also** **select** () and **currentChanged** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QAbstractNativeEventFilter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qabstractnativeeventfilter.html

    **Detailed Description**
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractnativeeventfilter.html#QAbstractNativeEv
        entFilter

        **QAbstractNativeEventFilter::QAbstractNativeEventFilter()**

        Creates a native event filter.

        By default this doesn't do anything. Remember to install it on the
        application object.
        """
        ...

    def nativeEventFilter(
        self, eventType: "QByteArray", message: PyQt6.sip.voidptr
    ) -> typing.Tuple[bool, PyQt6.sip.voidptr]:
        """
        https://doc.qt.io/qt-6/qabstractnativeeventfilter.html#nativeEventFilter

        **[pure virtual] bool
        QAbstractNativeEventFilter::nativeEventFilter(const QByteArray &
        eventType , void * message , qintptr * result )**

        This method is called for every native event.

        **Note:** The filter function here receives native messages, for
        example, MSG or XCB event structs.

        It is called by the QPA platform plugin. On Windows, it is called by the
        event dispatcher.

        The type of event **eventType** is specific to the platform plugin
        chosen at run-time, and can be used to cast **message** to the right
        type.

        On X11, **eventType** is set to "xcb_generic_event_t", and the
        **message** can be casted to a xcb_generic_event_t pointer.

        On Windows, **eventType** is set to "windows_generic_MSG" for messages
        sent to toplevel windows, and "windows_dispatcher_MSG" for system-wide
        messages such as messages from a registered hot key. In both cases, the
        **message** can be casted to a MSG pointer. The **result** pointer is
        only used on Windows, and corresponds to the LRESULT pointer.

        On macOS, **eventType** is set to "mac_generic_NSEvent", and the
        **message** can be casted to an NSEvent pointer.

        In your reimplementation of this function, if you want to filter the
        **message** out, i.e. stop it being handled further, return true;
        otherwise return false.

        **Linux example**

        class MyXcbEventFilter : public **QAbstractNativeEventFilter**
            {
        public:
                bool nativeEventFilter(const **QByteArray**  &eventType,
        void *message, long *) override
                {
                    if (eventType ==
        "xcb_generic_event_t") {
                        xcb_generic_event_t* ev =
        static_cast<xcb_generic_event_t \\*>(message);
                        // ...
        }
                    return false;
                }
            };

        **macOS example**

        mycocoaeventfilter.h:

        #include <QAbstractNativeEventFilter>

            class MyCocoaEventFilter
        : public **QAbstractNativeEventFilter**
            {
            public:
                bool
        nativeEventFilter(const **QByteArray**  &eventType, void *message, long
        *) override;
            };

        mycocoaeventfilter.mm:

        #include "mycocoaeventfilter.h"

            #import <AppKit/AppKit.h>
        bool CocoaNativeEventFilter::nativeEventFilter(const QByteArray
        &eventType, void *message, long *)
            {
                if (eventType ==
        "mac_generic_NSEvent") {
                    NSEvent *event =
        static_cast<NSEvent \\*>(message);
                    if ([event type] ==
        NSKeyDown) {
                        // Handle key event
        qDebug() << QString::fromNSString([event characters]);
                    }
        }
                return false;
            }

        myapp.pro:

        HEADERS += mycocoaeventfilter.h
            OBJECTIVE_SOURCES +=
        mycocoaeventfilter.mm
            LIBS += -framework AppKit
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
import datetime
from PyQt6.QtCore import *
import enum


class QCalendar(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcalendar.html

    **Detailed Description**

    A QCalendar object maps a year, month, and day-number to a specific day
    (ultimately identified by its Julian day number), using the rules of a
    particular system.

    The default QCalendar() is a proleptic Gregorian calendar, which has no year
    zero. Other calendars may be supported by enabling suitable features or
    loading plugins. Calendars supported as features can be constructed by
    passing the **QCalendar::System**  enumeration to the constructor. All
    supported calendars may be constructed by name, once they have been
    constructed. (Thus plugins instantiate their calendar backend to register
    it.) Built-in backends, accessible via **QCalendar::System** , are also
    always available by name. Calendars using custom backends may also be
    constructed using a unique ID allocated to the backend on construction.

    A QCalendar value is immutable.

    **See also** **QDate**  and **QDateTime** .
    """

    class System(enum.Enum):
        Gregorian: QCalendar = ...
        Julian: QCalendar = ...
        Milankovic: QCalendar = ...
        Jalali: QCalendar = ...
        IslamicCivil: QCalendar = ...

    Unspecified: int = ...

    class YearMonthDay(PyQt6.sip.simplewrapper):
        day: int = ...
        month: int = ...
        year: int = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, year: int, month: int = ..., day: int = ...) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QCalendar.YearMonthDay") -> None:
            ...

        def isValid(self) -> bool:
            ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendar.html#QCalendar-4

        **[since 6.2] QCalendar::QCalendar(QCalendar::SystemId id )**

        This is an overloaded function.

        Constructs a calendar object.

        When using a custom calendar implementation, its backend is allocated a
        unique ID when created; passing that as **id** to this constructor will
        get a QCalendar using that backend. This can be useful when the backend
        is not registered by name.

        This function was introduced in Qt 6.2.
        """
        ...

    @typing.overload
    def __init__(self, system: "QCalendar.System") -> None:
        """
        https://doc.qt.io/qt-6/qcalendar.html#QCalendar-4

        **[since 6.2] QCalendar::QCalendar(QCalendar::SystemId id )**

        This is an overloaded function.

        Constructs a calendar object.

        When using a custom calendar implementation, its backend is allocated a
        unique ID when created; passing that as **id** to this constructor will
        get a QCalendar using that backend. This can be useful when the backend
        is not registered by name.

        This function was introduced in Qt 6.2.
        """
        ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qcalendar.html#QCalendar-4

        **[since 6.2] QCalendar::QCalendar(QCalendar::SystemId id )**

        This is an overloaded function.

        Constructs a calendar object.

        When using a custom calendar implementation, its backend is allocated a
        unique ID when created; passing that as **id** to this constructor will
        get a QCalendar using that backend. This can be useful when the backend
        is not registered by name.

        This function was introduced in Qt 6.2.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QCalendar") -> None:
        """
        https://doc.qt.io/qt-6/qcalendar.html#QCalendar-4

        **[since 6.2] QCalendar::QCalendar(QCalendar::SystemId id )**

        This is an overloaded function.

        Constructs a calendar object.

        When using a custom calendar implementation, its backend is allocated a
        unique ID when created; passing that as **id** to this constructor will
        get a QCalendar using that backend. This can be useful when the backend
        is not registered by name.

        This function was introduced in Qt 6.2.
        """
        ...

    @staticmethod
    def availableCalendars() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qcalendar.html#availableCalendars

        **[static] QStringList QCalendar::availableCalendars()**

        Returns a list of names of the available calendar systems.

        These may be supplied by plugins or other code linked into an
        application, in addition to the ones provided by Qt, some of which are
        controlled by features.
        """
        ...

    def dateTimeToString(
        self,
        format: str,
        datetime: typing.Union["QDateTime", datetime.datetime],
        dateOnly: typing.Union["QDate", datetime.date],
        timeOnly: typing.Union["QTime", datetime.time],
        locale: "QLocale",
    ) -> str:
        """
        https://doc.qt.io/qt-6/qcalendar.html#dateTimeToString

        **QString QCalendar::dateTimeToString(QStringView format , const
        QDateTime & datetime , QDate dateOnly , QTime timeOnly , const QLocale &
        locale ) const**

        Returns a string representing a given date, time or date-time.

        If **datetime** is valid, it is represented and format specifiers for
        both date and time fields are recognized; otherwise, if **dateOnly** is
        valid, it is represented and only format specifiers for date fields are
        recognized; finally, if **timeOnly** is valid, it is represented and
        only format specifiers for time fields are recognized. If none of these
        is valid, an empty string is returned.

        See **QDate::toString**  and **QTime::toString** () for the supported
        field specifiers. Characters in **format** that are recognized as field
        specifiers are replaced by text representing appropriate data from the
        date and/or time being represented. The texts to represent them may
        depend on the **locale** specified. Other charagers in **format** are
        copied verbatim into the returned string.

        **See also** **monthName** (), **weekDayName** (), **QDate::toString**
        (), and **QTime::toString** ().
        """
        ...

    def standaloneWeekDayName(
        self, locale: "QLocale", day: int, format: "QLocale.FormatType" = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qcalendar.html#standaloneWeekDayName

        **QString QCalendar::standaloneWeekDayName(const QLocale & locale , int
        day , QLocale::FormatType format = QLocale::LongFormat) const**

        Returns a suitably localised standalone name for a day of the week.

        The days of the week are numbered from 1 for Monday through 7 for
        Sunday. Some calendars may support higher numbers for other days (e.g.
        intercallary days, that are not part of any week). Returns an empty
        string if the **day** number is unrecognized.

        The name is returned in the form that would be used in isolation (for
        example as a column heading in a calendar's tabular display of a month
        with successive weeks as rows) in the specified **locale** ; the
        **format** determines how fully it shall be expressed (i.e. to what
        extent it is abbreviated).

        **See also** **weekDayName** () and **dayOfWeek** ().
        """
        ...

    def weekDayName(
        self, locale: "QLocale", day: int, format: "QLocale.FormatType" = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qcalendar.html#weekDayName

        **QString QCalendar::weekDayName(const QLocale & locale , int day ,
        QLocale::FormatType format = QLocale::LongFormat) const**

        Returns a suitably localised name for a day of the week.

        The days of the week are numbered from 1 for Monday through 7 for
        Sunday. Some calendars may support higher numbers for other days (e.g.
        intercallary days, that are not part of any week). Returns an empty
        string if the **day** number is unrecognized.

        The name is returned in the form that would normally be used in a full
        date, in the specified **locale** ; the **format** determines how fully
        it shall be expressed (i.e. to what extent it is abbreviated).

        **See also** **standaloneWeekDayName** () and **dayOfWeek** ().
        """
        ...

    def standaloneMonthName(
        self,
        locale: "QLocale",
        month: int,
        year: int = ...,
        format: "QLocale.FormatType" = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qcalendar.html#standaloneMonthName

        **QString QCalendar::standaloneMonthName(const QLocale & locale , int
        month , int year = Unspecified, QLocale::FormatType format =
        QLocale::LongFormat) const**

        Returns a suitably localised standalone name for a month.

        The month is indicated by a number, with **month** = 1 meaning the first
        month of the year and subsequent months numbered accordingly. Returns an
        empty string if the **month** number is unrecognized.

        The **year** may be Unspecified, in which case the mapping from numbers
        to names for a typical year's months should be used. Some calendars have
        leap months that aren't always at the end of the year; their mapping of
        month numbers to names may then depend on the placement of a leap month.
        Thus the year should normally be specified, if known.

        The name is returned in the form that would be used in isolation in the
        specified **locale** ; the **format** determines how fully it shall be
        expressed (i.e. to what extent it is abbreviated).

        **See also** **monthName** (), **maximumMonthsInYear** (), and
        **dateTimeToString** ().
        """
        ...

    def monthName(
        self,
        locale: "QLocale",
        month: int,
        year: int = ...,
        format: "QLocale.FormatType" = ...,
    ) -> str:
        """
        https://doc.qt.io/qt-6/qcalendar.html#monthName

        **QString QCalendar::monthName(const QLocale & locale , int month , int
        year = Unspecified, QLocale::FormatType format = QLocale::LongFormat)
        const**

        Returns a suitably localised name for a month.

        The month is indicated by a number, with **month** = 1 meaning the first
        month of the year and subsequent months numbered accordingly. Returns an
        empty string if the **month** number is unrecognized.

        The **year** may be Unspecified, in which case the mapping from numbers
        to names for a typical year's months should be used. Some calendars have
        leap months that aren't always at the end of the year; their mapping of
        month numbers to names may then depend on the placement of a leap month.
        Thus the year should normally be specified, if known.

        The name is returned in the form that would normally be used in a full
        date, in the specified **locale** ; the **format** determines how fully
        it shall be expressed (i.e. to what extent it is abbreviated).

        **See also** **standaloneMonthName** (), **maximumMonthsInYear** (), and
        **dateTimeToString** ().
        """
        ...

    def dayOfWeek(self, date: typing.Union["QDate", datetime.date]) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#dayOfWeek

        **int QCalendar::dayOfWeek(QDate date ) const**

        Returns the day of the week number for the given **date**.

        Returns zero if the calendar is unable to represent the indicated date.
        Returns 1 for Monday through 7 for Sunday. Calendars with intercallary
        days may use other numbers to represent these.

        **See also** **partsFromDate** () and **Qt::DayOfWeek** .
        """
        ...

    def partsFromDate(
        self, date: typing.Union["QDate", datetime.date]
    ) -> "QCalendar.YearMonthDay":
        """
        https://doc.qt.io/qt-6/qcalendar.html#partsFromDate

        **QCalendar::YearMonthDay QCalendar::partsFromDate(QDate date ) const**

        Converts a **QDate**  to a year, month, and day of the month.

        The returned structure's **isValid** () shall be false if the calendar
        is unable to represent the given **date**. Otherwise its year, month,
        and day members record the so-named parts of its representation.

        **See also** **dateFromParts** (), **isProleptic** (), and
        **hasYearZero** ().
        """
        ...

    @typing.overload
    def dateFromParts(self, year: int, month: int, day: int) -> "QDate":
        ...

    @typing.overload
    def dateFromParts(self, parts: "QCalendar.YearMonthDay") -> "QDate":
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qcalendar.html#name

        **QString QCalendar::name() const**

        The primary name of this calendar.

        The calendar may also be known by some aliases. A calendar instantiated
        by name may use such an alias, in which case its name() need not match
        the alias by which it was instantiated.
        """
        ...

    def maximumMonthsInYear(self) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#maximumMonthsInYear

        **int QCalendar::maximumMonthsInYear() const**

        Returns the largest number of months that any year may contain.

        **See also** **monthName** (), **standaloneMonthName** (), and
        **monthsInYear** ().
        """
        ...

    def minimumDaysInMonth(self) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#minimumDaysInMonth

        **int QCalendar::minimumDaysInMonth() const**

        Returns the number of days in the shortest month in the calendar, in any
        year.

        **See also** **daysInMonth** () and **maximumDaysInMonth** ().
        """
        ...

    def maximumDaysInMonth(self) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#maximumDaysInMonth

        **int QCalendar::maximumDaysInMonth() const**

        Returns the number of days in the longest month in the calendar, in any
        year.

        **See also** **daysInMonth** () and **minimumDaysInMonth** ().
        """
        ...

    def hasYearZero(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#hasYearZero

        **bool QCalendar::hasYearZero() const**

        Returns `true` if this calendar has a year zero.

        A calendar may represent years from its first year onwards but provide
        no way to describe years before its first; such a calendar has no year
        zero and is not proleptic.

        A calendar which represents years before its first may number these
        years simply by following the usual integer counting, so that the year
        before the first is year zero, with negative-numbered years preceding
        this; such a calendar is proleptic and has a year zero. A calendar might
        also have a year zero (for example, the year of some great event, with
        subsequent years being the first year after that event, the second year
        after, and so on) without describing years before its year zero. Such a
        calendar would have a year zero without being proleptic.

        Some calendars, however, represent years before their first by an
        alternate numbering; for example, the proleptic Gregorian calendar's
        first year is 1 CE and the year before it is 1 BCE, preceded by 2 BCE
        and so on. In this case, we use negative year numbers for this alternate
        numbering, with year -1 as the year before year 1, year -2 as the year
        before year -1 and so on. Such a calendar is proleptic but has no year
        zero.

        **See also** **isProleptic** ().
        """
        ...

    def isProleptic(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isProleptic

        **bool QCalendar::isProleptic() const**

        Returns `true` if this calendar is proleptic.

        A proleptic calendar is able to describe years arbitrarily long before
        its first. These are represented by negative year numbers and possibly
        by a year zero.

        **See also** **hasYearZero** ().
        """
        ...

    def isSolar(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isSolar

        **bool QCalendar::isSolar() const**

        Returns `true` if this calendar is solar.

        A solar calendar is based primarily on the Sun's varying position in the
        sky, relative to the fixed stars.
        """
        ...

    def isLuniSolar(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isLuniSolar

        **bool QCalendar::isLuniSolar() const**

        Returns `true` if this calendar is luni-solar.

        A luni-solar calendar expresses the phases of the moon but adapts itself
        to also keep track of the Sun's varying position in the sky, relative to
        the fixed stars.
        """
        ...

    def isLunar(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isLunar

        **bool QCalendar::isLunar() const**

        Returns `true` if this calendar is a lunar calendar.

        A lunar calendar is one based primarily on the phases of the moon.
        """
        ...

    def isGregorian(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isGregorian

        **bool QCalendar::isGregorian() const**

        Returns `true` if this calendar object is the Gregorian calendar object
        used as default calendar by other Qt APIs, e.g. in **QDate** .
        """
        ...

    def isLeapYear(self, year: int) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isLeapYear

        **bool QCalendar::isLeapYear(int year ) const**

        Returns `true` if the given **year** is a leap year.

        Since the year is not a whole number of days long, some years are longer
        than others. The difference may be a whole month or just a single day;
        the details vary between calendars.

        **See also** **isDateValid** ().
        """
        ...

    def isDateValid(self, year: int, month: int, day: int) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendar.html#isDateValid

        **bool QCalendar::isDateValid(int year , int month , int day ) const**

        Returns `true` precisely if the given **year** , **month** , and **day**
        specify a valid date in this calendar.

        Usually this means 1 <= month <= **monthsInYear** (year) and 1 <= day <=
        **daysInMonth** (month, year). However, calendars with intercallary days
        or months may complicate that.
        """
        ...

    def monthsInYear(self, year: int) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#monthsInYear

        **int QCalendar::monthsInYear(int year ) const**

        Returns the number of months in the given **year**.

        If **year** is `Unspecified`, returns the maximum number of months in a
        year.

        **See also** **maximumMonthsInYear** ().
        """
        ...

    def daysInYear(self, year: int) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#daysInYear

        **int QCalendar::daysInYear(int year ) const**

        Returns the number of days in the given **year**.

        Handling of `Unspecified` as **year** is undefined.
        """
        ...

    def daysInMonth(self, month: int, year: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qcalendar.html#daysInMonth

        **int QCalendar::daysInMonth(int month , int year = Unspecified) const**

        Returns the number of days in the given **month** of the given **year**.

        Months are numbered consecutively, starting with 1 for the first month
        of each year. If **year** is `Unspecified` (its default, if not passed),
        the month's length in a normal year is returned.

        **See also** **maximumDaysInMonth** () and **minimumDaysInMonth** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsAnchorLayout(QGraphicsLayout):
    """
    https://doc.qt.io/qt-6/qgraphicsanchorlayout.html

    **Detailed Description**

    The anchor layout allows developers to specify how widgets should be placed
    relative to each other, and to the layout itself. The specification is made
    by adding anchors to the layout by calling **addAnchor** (), **addAnchors**
    () or **addCornerAnchors** ().

    Existing anchors in the layout can be accessed with the **anchor** ()
    function. Items that are anchored are automatically added to the layout, and
    if items are removed, all their anchors will be automatically removed.

    ![Using an anchor layout to align simple colored
    widgets.](images/simpleanchorlayout-example.png)

    Anchors are always set up between edges of an item, where the "center" is
    also considered to be an edge. Consider the following example:

    layout->addAnchor(b, Qt::AnchorLeft, a, Qt::AnchorRight);
    layout->addAnchor(b, Qt::AnchorTop, a, Qt::AnchorBottom);

    Here, the right edge of item `a` is anchored to the left edge of item `b`
    and the bottom edge of item `a` is anchored to the top edge of item `b`,
    with the result that item `b` will be placed diagonally to the right and
    below item `b`.

    The **addCornerAnchors** () function provides a simpler way of anchoring the
    corners of two widgets than the two individual calls to **addAnchor** ()
    shown in the code above. Here, we see how a widget can be anchored to the
    top-left corner of the enclosing layout:

    layout->addCornerAnchors(a, Qt::TopLeftCorner, layout, Qt::TopLeftCorner);

    In cases where anchors are used to match the widths or heights of widgets,
    it is convenient to use the **addAnchors** () function. As with the other
    functions for specifying anchors, it can also be used to anchor a widget to
    a layout.

    **Size Hints and Size Policies in an Anchor Layout**

    QGraphicsAnchorLayout respects each item's size hints and size policies.
    Note that there are some properties of **QSizePolicy**  that are **not
    respected** .

    **Spacing within an Anchor Layout**

    The layout may distribute some space between the items. If the spacing has
    not been explicitly specified, the actual amount of space will usually be 0.

    However, if the first edge is the **opposite** of the second edge (e.g., the
    right edge of the first widget is anchored to the left edge of the second
    widget), the size of the anchor will be queried from the style through a
    pixel metric: **PM_LayoutHorizontalSpacing**  for horizontal anchors and
    **PM_LayoutVerticalSpacing**  for vertical anchors.

    If the spacing is negative, the items will overlap to some extent.

    **Known Issues**

    There are some features that QGraphicsAnchorLayout currently does not
    support. This might change in the future, so avoid using these features if
    you want to avoid any future regressions in behaviour:

    * Stretch factors are not respected.
      * **QSizePolicy::ExpandFlag**  is not
    respected.
      * Height for width is not respected.

    **See also** **QGraphicsLinearLayout** , **QGraphicsGridLayout** , and
    **QGraphicsLayout** .
    """

    def __init__(self, parent: typing.Optional[QGraphicsLayoutItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#QGraphicsAnchorLayout

        **QGraphicsAnchorLayout::QGraphicsAnchorLayout(QGraphicsLayoutItem *
        parent = nullptr)**

        Constructs a QGraphicsAnchorLayout instance. **parent** is passed to
        **QGraphicsLayout** 's constructor.
        """
        ...

    def sizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#sizeHint

        **[override virtual protected] QSizeF
        QGraphicsAnchorLayout::sizeHint(Qt::SizeHint which , const QSizeF &
        constraint = QSizeF()) const**

        Reimplements: **QGraphicsLayoutItem::sizeHint(Qt::SizeHint which, const
        QSizeF &constraint) const** .
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#invalidate

        **[override virtual] void QGraphicsAnchorLayout::invalidate()**

        Reimplements: **QGraphicsLayout::invalidate** ().
        """
        ...

    def itemAt(self, index: int) -> QGraphicsLayoutItem:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#itemAt

        **[override virtual] QGraphicsLayoutItem
        *QGraphicsAnchorLayout::itemAt(int index ) const**

        Reimplements: **QGraphicsLayout::itemAt(int i) const** .
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#count

        **[override virtual] int QGraphicsAnchorLayout::count() const**

        Reimplements: **QGraphicsLayout::count() const** .
        """
        ...

    def setGeometry(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#setGeometry

        **[override virtual] void QGraphicsAnchorLayout::setGeometry(const
        QRectF & geom )**

        Reimplements: **QGraphicsLayoutItem::setGeometry** (const QRectF &rect).
        """
        ...

    def removeAt(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#removeAt

        **[override virtual] void QGraphicsAnchorLayout::removeAt(int index )**

        Reimplements: **QGraphicsLayout::removeAt** (int index).

        Removes the layout item at **index** without destroying it. Ownership of
        the item is transferred to the caller.

        Removing an item will also remove any of the anchors associated with it.

        **See also** **itemAt** () and **count** ().
        """
        ...

    def verticalSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#verticalSpacing

        **qreal QGraphicsAnchorLayout::verticalSpacing() const**

        Returns the default vertical spacing for the anchor layout.

        **See also** **horizontalSpacing** () and **setVerticalSpacing** ().
        """
        ...

    def horizontalSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#horizontalSpacing

        **qreal QGraphicsAnchorLayout::horizontalSpacing() const**

        Returns the default horizontal spacing for the anchor layout.

        **See also** **verticalSpacing** () and **setHorizontalSpacing** ().
        """
        ...

    def setSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#setSpacing

        **void QGraphicsAnchorLayout::setSpacing(qreal spacing )**

        Sets the default horizontal and the default vertical spacing for the
        anchor layout to **spacing**.

        If an item is anchored with no spacing associated with the anchor, it
        will use the default spacing.

        **QGraphicsAnchorLayout**  does not support negative spacings. Setting a
        negative value will unset the previous spacing and make the layout use
        the spacing provided by the current widget style.

        **See also** **setHorizontalSpacing** () and **setVerticalSpacing** ().
        """
        ...

    def setVerticalSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#setVerticalSpacing

        **void QGraphicsAnchorLayout::setVerticalSpacing(qreal spacing )**

        Sets the default vertical spacing for the anchor layout to **spacing**.

        **See also** **verticalSpacing** (), **setHorizontalSpacing** (), and
        **setSpacing** ().
        """
        ...

    def setHorizontalSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#setHorizontalSpacing

        **void QGraphicsAnchorLayout::setHorizontalSpacing(qreal spacing )**

        Sets the default horizontal spacing for the anchor layout to
        **spacing**.

        **See also** **horizontalSpacing** (), **setVerticalSpacing** (), and
        **setSpacing** ().
        """
        ...

    def addAnchors(
        self,
        firstItem: QGraphicsLayoutItem,
        secondItem: QGraphicsLayoutItem,
        orientations: QtCore.Qt.Orientation = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#addAnchors

        **void QGraphicsAnchorLayout::addAnchors(QGraphicsLayoutItem * firstItem
        , QGraphicsLayoutItem * secondItem , Qt::Orientations orientations =
        Qt::Horizontal | Qt::Vertical)**

        Anchors two or four edges of **firstItem** with the corresponding edges
        of **secondItem** , so that **firstItem** has the same size as
        **secondItem** in the dimensions specified by **orientations**.

        For example, the following example anchors the left and right edges of
        two items to match their widths:

        layout->addAnchor(b, Qt::AnchorLeft, c, Qt::AnchorLeft);
        layout->addAnchor(b, Qt::AnchorRight, c, Qt::AnchorRight);

        This can also be achieved using the following line of code:

        layout->addAnchors(b, c, Qt::Horizontal);

        **See also** **addAnchor** () and **addCornerAnchors** ().
        """
        ...

    def addCornerAnchors(
        self,
        firstItem: QGraphicsLayoutItem,
        firstCorner: QtCore.Qt.Corner,
        secondItem: QGraphicsLayoutItem,
        secondCorner: QtCore.Qt.Corner,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#addCornerAnchors

        **void QGraphicsAnchorLayout::addCornerAnchors(QGraphicsLayoutItem *
        firstItem , Qt::Corner firstCorner , QGraphicsLayoutItem * secondItem ,
        Qt::Corner secondCorner )**

        Creates two anchors between **firstItem** and **secondItem** specified
        by the corners, **firstCorner** and **secondCorner** , where one is for
        the horizontal edge and another one for the vertical edge.

        This is a convenience function, since anchoring corners can be expressed
        as anchoring two edges. For instance:

        layout->addAnchor(a, Qt::AnchorTop, layout, Qt::AnchorTop);
        layout->addAnchor(a, Qt::AnchorLeft, layout, Qt::AnchorLeft);

        This can also be achieved with the following line of code:

        layout->addCornerAnchors(a, Qt::TopLeftCorner, layout,
        Qt::TopLeftCorner);

        If there is already an anchor between the edge pairs, it will be
        replaced by the anchors that this function specifies.

        **firstItem** and **secondItem** are automatically added to the layout
        if they are not part of the layout. This means that **count** () can
        increase by up to 2.

        **See also** **addAnchor** () and **addAnchors** ().
        """
        ...

    def anchor(
        self,
        firstItem: QGraphicsLayoutItem,
        firstEdge: QtCore.Qt.AnchorPoint,
        secondItem: QGraphicsLayoutItem,
        secondEdge: QtCore.Qt.AnchorPoint,
    ) -> QGraphicsAnchor:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#anchor

        **QGraphicsAnchor *QGraphicsAnchorLayout::anchor(QGraphicsLayoutItem *
        firstItem , Qt::AnchorPoint firstEdge , QGraphicsLayoutItem * secondItem
        , Qt::AnchorPoint secondEdge )**

        Returns the anchor between the anchor points defined by **firstItem**
        and **firstEdge** and **secondItem** and **secondEdge**. If there is no
        such anchor, the function will return 0.
        """
        ...

    def addAnchor(
        self,
        firstItem: QGraphicsLayoutItem,
        firstEdge: QtCore.Qt.AnchorPoint,
        secondItem: QGraphicsLayoutItem,
        secondEdge: QtCore.Qt.AnchorPoint,
    ) -> QGraphicsAnchor:
        """
        https://doc.qt.io/qt-6/qgraphicsanchorlayout.html#addAnchor

        **QGraphicsAnchor *QGraphicsAnchorLayout::addAnchor(QGraphicsLayoutItem
        * firstItem , Qt::AnchorPoint firstEdge , QGraphicsLayoutItem *
        secondItem , Qt::AnchorPoint secondEdge )**

        Creates an anchor between the edge **firstEdge** of item **firstItem**
        and the edge **secondEdge** of item **secondItem**. The spacing of the
        anchor is picked up from the style. Anchors between a layout edge and an
        item edge will have a size of 0. If there is already an anchor between
        the edges, the new anchor will replace the old one.

        **firstItem** and **secondItem** are automatically added to the layout
        if they are not part of the layout. This means that **count** () can
        increase by up to 2.

        The spacing an anchor will get depends on the type of anchor. For
        instance, anchors from the Right edge of one item to the Left edge of
        another (or vice versa) will use the default horizontal spacing. The
        same behaviour applies to Bottom to Top anchors, (but they will use the
        default vertical spacing). For all other anchor combinations, the
        spacing will be 0. All anchoring functions will follow this rule.

        The spacing can also be set manually by using
        **QGraphicsAnchor::setSpacing** () method.

        Calling this function where **firstItem** or **secondItem** are
        ancestors of the layout have undefined behaviour.

        **See also** **addAnchors** () and **addCornerAnchors** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QVector2D(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qvector2d.html

    **Detailed Description**

    Vectors are one of the main building blocks of 2D representation and
    drawing. They consist of two finite floating-point coordinates,
    traditionally called x and y.

    The QVector2D class can also be used to represent vertices in 2D space. We
    therefore do not need to provide a separate vertex class.

    **See also** **QVector3D** , **QVector4D** , and **QQuaternion** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D

        **QVector2D::QVector2D()**

        Constructs a null vector, i.e. with coordinates (0, 0).
        """
        ...

    @typing.overload
    def __init__(self, xpos: float, ypos: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D-2

        **QVector2D::QVector2D(float xpos , float ypos )**

        Constructs a vector with coordinates ( **xpos** , **ypos** ). Both
        coordinates must be finite.
        """
        ...

    @typing.overload
    def __init__(self, point: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D-3

        **QVector2D::QVector2D(QPoint point )**

        Constructs a vector with x and y coordinates from a 2D **point**.
        """
        ...

    @typing.overload
    def __init__(self, point: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D-4

        **QVector2D::QVector2D(QPointF point )**

        Constructs a vector with x and y coordinates from a 2D **point**.
        """
        ...

    @typing.overload
    def __init__(self, vector: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D-5

        **QVector2D::QVector2D(QVector3D vector )**

        Constructs a vector with x and y coordinates from a 3D **vector**. The z
        coordinate of **vector** is dropped.

        **See also** **toVector3D** ().
        """
        ...

    @typing.overload
    def __init__(self, vector: "QVector4D") -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D-6

        **QVector2D::QVector2D(QVector4D vector )**

        Constructs a vector with x and y coordinates from a 3D **vector**. The z
        and w coordinates of **vector** are dropped.

        **See also** **toVector4D** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QVector2D") -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#QVector2D

        **QVector2D::QVector2D()**

        Constructs a null vector, i.e. with coordinates (0, 0).
        """
        ...

    def __neg__(self) -> "QVector2D":
        ...

    def toPointF(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qvector2d.html#toPointF

        **QPointF QVector2D::toPointF() const**

        Returns the **QPointF**  form of this 2D vector.

        **See also** **toPoint** () and **toVector3D** ().
        """
        ...

    def toPoint(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qvector2d.html#toPoint

        **QPoint QVector2D::toPoint() const**

        Returns the **QPoint**  form of this 2D vector. Each coordinate is
        rounded to the nearest integer.

        **See also** **toPointF** () and **toVector3D** ().
        """
        ...

    def toVector4D(self) -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qvector2d.html#toVector4D

        **QVector4D QVector2D::toVector4D() const**

        Returns the 4D form of this 2D vector, with the z and w coordinates set
        to zero.

        **See also** **toVector3D** () and **toPoint** ().
        """
        ...

    def toVector3D(self) -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector2d.html#toVector3D

        **QVector3D QVector2D::toVector3D() const**

        Returns the 3D form of this 2D vector, with the z coordinate set to
        zero.

        **See also** **toVector4D** () and **toPoint** ().
        """
        ...

    @staticmethod
    def dotProduct(v1: "QVector2D", v2: "QVector2D") -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#dotProduct

        **[static] float QVector2D::dotProduct(QVector2D v1 , QVector2D v2 )**

        Returns the dot product of **v1** and **v2**.
        """
        ...

    def distanceToLine(self, point: "QVector2D", direction: "QVector2D") -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#distanceToLine

        **[since 5.1] float QVector2D::distanceToLine(QVector2D point ,
        QVector2D direction ) const**

        Returns the distance that this vertex is from a line defined by
        **point** and the unit vector **direction**.

        If **direction** is a null vector, then it does not define a line. In
        that case, the distance from **point** to this vertex is returned.

        This function was introduced in Qt 5.1.

        **See also** **distanceToPoint** ().
        """
        ...

    def distanceToPoint(self, point: "QVector2D") -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#distanceToPoint

        **[since 5.1] float QVector2D::distanceToPoint(QVector2D point ) const**

        Returns the distance from this vertex to a point defined by the vertex
        **point**.

        This function was introduced in Qt 5.1.

        **See also** **distanceToLine** ().
        """
        ...

    def normalize(self) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#normalize

        **void QVector2D::normalize()**

        Normalizes the currect vector in place. Nothing happens if this vector
        is a null vector or the length of the vector is very close to 1.

        **See also** **length** () and **normalized** ().
        """
        ...

    def normalized(self) -> "QVector2D":
        """
        https://doc.qt.io/qt-6/qvector2d.html#normalized

        **QVector2D QVector2D::normalized() const**

        Returns the normalized unit vector form of this vector.

        If this vector is null, then a null vector is returned. If the length of
        the vector is very close to 1, then the vector will be returned as-is.
        Otherwise the normalized form of the vector of length 1 will be
        returned.

        **See also** **length** () and **normalize** ().
        """
        ...

    def lengthSquared(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#lengthSquared

        **float QVector2D::lengthSquared() const**

        Returns the squared length of the vector from the origin. This is
        equivalent to the dot product of the vector with itself.

        **See also** **length** () and **dotProduct** ().
        """
        ...

    def length(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#length

        **float QVector2D::length() const**

        Returns the length of the vector from the origin.

        **See also** **lengthSquared** () and **normalized** ().
        """
        ...

    def __getitem__(self, i: int) -> float:
        ...

    def setY(self, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#setY

        **void QVector2D::setY(float y )**

        Sets the y coordinate of this point to the given finite **y**
        coordinate.

        **See also** **y** () and **setX** ().
        """
        ...

    def setX(self, x: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector2d.html#setX

        **void QVector2D::setX(float x )**

        Sets the x coordinate of this point to the given finite **x**
        coordinate.

        **See also** **x** () and **setY** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#y

        **float QVector2D::y() const**

        Returns the y coordinate of this point.

        **See also** **setY** () and **x** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector2d.html#x

        **float QVector2D::x() const**

        Returns the x coordinate of this point.

        **See also** **setX** () and **y** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvector2d.html#isNull

        **bool QVector2D::isNull() const**

        Returns `true` if the x and y coordinates are set to 0.0, otherwise
        returns `false`.
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QTextBoundaryFinder(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtextboundaryfinder.html

    **Detailed Description**

    QTextBoundaryFinder allows to find Unicode text boundaries in a string,
    accordingly to the Unicode text boundary specification (see **Unicode
    Standard Annex #14**  and **Unicode Standard Annex #29** ).

    QTextBoundaryFinder can operate on a **QString**  in four possible modes
    depending on the value of **BoundaryType**.

    Units of Unicode characters that make up what the user thinks of as a
    character or basic unit of the language are here called Grapheme clusters.
    The two unicode characters 'A' + diaeresis do for example form one grapheme
    cluster as the user thinks of them as one character, yet it is in this case
    represented by two unicode code points (see
    <https://www.unicode.org/reports/tr29/#Grapheme_Cluster_Boundaries>).

    Word boundaries are there to locate the start and end of what a language
    considers to be a word (see
    <https://www.unicode.org/reports/tr29/#Word_Boundaries>).

    Line break boundaries give possible places where a line break might happen
    and sentence boundaries will show the beginning and end of whole sentences
    (see <https://www.unicode.org/reports/tr29/#Sentence_Boundaries> and
    <https://www.unicode.org/reports/tr14/>).

    The first position in a string is always a valid boundary and refers to the
    position before the first character. The last position at the length of the
    string is also valid and refers to the position after the last character.
    """

    class BoundaryType(enum.Enum):
        Grapheme: QTextBoundaryFinder = ...
        Word: QTextBoundaryFinder = ...
        Line: QTextBoundaryFinder = ...
        Sentence: QTextBoundaryFinder = ...

    class BoundaryReason(enum.Flag):
        NotAtBoundary: QTextBoundaryFinder = ...
        SoftHyphen: QTextBoundaryFinder = ...
        BreakOpportunity: QTextBoundaryFinder = ...
        StartOfItem: QTextBoundaryFinder = ...
        EndOfItem: QTextBoundaryFinder = ...
        MandatoryBreak: QTextBoundaryFinder = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#QTextBoundaryFinder

        **QTextBoundaryFinder::QTextBoundaryFinder()**

        Constructs an invalid QTextBoundaryFinder object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QTextBoundaryFinder") -> None:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#QTextBoundaryFinder-1

        **QTextBoundaryFinder::QTextBoundaryFinder(const QTextBoundaryFinder &
        other )**

        Copies the QTextBoundaryFinder object, **other**.
        """
        ...

    @typing.overload
    def __init__(self, type: "QTextBoundaryFinder.BoundaryType", string: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#QTextBoundaryFinder-2

        **QTextBoundaryFinder::QTextBoundaryFinder(QTextBoundaryFinder::Boundary
        Type type , const QString & string )**

        Creates a QTextBoundaryFinder object of **type** operating on
        **string**.
        """
        ...

    def boundaryReasons(self) -> "QTextBoundaryFinder.BoundaryReason":
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#boundaryReasons

        **QTextBoundaryFinder::BoundaryReasons
        QTextBoundaryFinder::boundaryReasons() const**

        Returns the reasons for the boundary finder to have chosen the current
        position as a boundary.
        """
        ...

    def isAtBoundary(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#isAtBoundary

        **bool QTextBoundaryFinder::isAtBoundary() const**

        Returns `true` if the object's **position** () is currently at a valid
        text boundary.
        """
        ...

    def toPreviousBoundary(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#toPreviousBoundary

        **qsizetype QTextBoundaryFinder::toPreviousBoundary()**

        Moves the **QTextBoundaryFinder**  to the previous boundary position and
        returns that position.

        Returns -1 if there is no previous boundary.
        """
        ...

    def toNextBoundary(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#toNextBoundary

        **qsizetype QTextBoundaryFinder::toNextBoundary()**

        Moves the **QTextBoundaryFinder**  to the next boundary position and
        returns that position.

        Returns -1 if there is no next boundary.
        """
        ...

    def setPosition(self, position: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#setPosition

        **void QTextBoundaryFinder::setPosition(qsizetype position )**

        Sets the current position of the **QTextBoundaryFinder**  to
        **position**.

        If **position** is out of bounds, it will be bound to only valid
        positions. In this case, valid positions are from 0 to the length of the
        string inclusive.

        **See also** **position** ().
        """
        ...

    def position(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#position

        **qsizetype QTextBoundaryFinder::position() const**

        Returns the current position of the **QTextBoundaryFinder** .

        The range is from 0 (the beginning of the string) to the length of the
        string inclusive.

        **See also** **setPosition** ().
        """
        ...

    def toEnd(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#toEnd

        **void QTextBoundaryFinder::toEnd()**

        Moves the finder to the end of the string. This is equivalent to
        **setPosition** (string.length()).

        **See also** **setPosition** () and **position** ().
        """
        ...

    def toStart(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#toStart

        **void QTextBoundaryFinder::toStart()**

        Moves the finder to the start of the string. This is equivalent to
        **setPosition** (0).

        **See also** **setPosition** () and **position** ().
        """
        ...

    def string(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#string

        **QString QTextBoundaryFinder::string() const**

        Returns the string the **QTextBoundaryFinder**  object operates on.
        """
        ...

    def type(self) -> "QTextBoundaryFinder.BoundaryType":
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#type

        **QTextBoundaryFinder::BoundaryType QTextBoundaryFinder::type() const**

        Returns the type of the **QTextBoundaryFinder** .
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextboundaryfinder.html#isValid

        **bool QTextBoundaryFinder::isValid() const**

        Returns `true` if the text boundary finder is valid; otherwise returns
        `false`. A default **QTextBoundaryFinder**  is invalid.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPaintEngineState(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpaintenginestate.html

    **Detailed Description**

    QPaintEngineState records which properties that have changed since the last
    time the paint engine was updated, as well as their current value.

    Which properties that have changed can at any time be retrieved using the
    **state** () function. This function returns an instance of the
    **QPaintEngine::DirtyFlags**  type which stores an OR combination of
    **QPaintEngine::DirtyFlag**  values. The **QPaintEngine::DirtyFlag**  enum
    defines whether a property has changed since the last update or not.

    If a property is marked with a dirty flag, its current value can be
    retrieved using the corresponding get function:

    Property FlagCurrent Property Value
    **QPaintEngine::DirtyBackground**
    **backgroundBrush** ()
    **QPaintEngine::DirtyBackgroundMode**
    **backgroundMode** ()
    **QPaintEngine::DirtyBrush** **brush** ()
    **QPaintEngine::DirtyBrushOrigin** **brushOrigin** ()
    **QPaintEngine::DirtyClipRegion**  **or** **QPaintEngine::DirtyClipPath**
    **clipOperation** ()
    **QPaintEngine::DirtyClipPath** **clipPath** ()
    **QPaintEngine::DirtyClipRegion** **clipRegion** ()
    **QPaintEngine::DirtyCompositionMode** **compositionMode** ()
    **QPaintEngine::DirtyFont** **font** ()
    **QPaintEngine::DirtyTransform**
    **transform** ()
    **QPaintEngine::DirtyClipEnabled** **isClipEnabled** ()
    **QPaintEngine::DirtyPen** **pen** ()
    **QPaintEngine::DirtyHints**
    **renderHints** ()

    The QPaintEngineState class also provide the **painter** () function which
    returns a pointer to the painter that is currently updating the paint
    engine.

    An instance of this class, representing the current state of the active
    paint engine, is passed as argument to the **QPaintEngine::updateState** ()
    function. The only situation in which you will have to use this class
    directly is when implementing your own paint engine.

    **See also** **QPaintEngine** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QPaintEngineState") -> None:
        ...

    def penNeedsResolving(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#penNeedsResolving

        **bool QPaintEngineState::penNeedsResolving() const**

        Returns whether the coordinate of the stroke have been specified as
        bounded by the current rendering operation and have to be resolved
        (about the currently rendered primitive).
        """
        ...

    def brushNeedsResolving(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#brushNeedsResolving

        **bool QPaintEngineState::brushNeedsResolving() const**

        Returns whether the coordinate of the fill have been specified as
        bounded by the current rendering operation and have to be resolved
        (about the currently rendered primitive).
        """
        ...

    def transform(self) -> "QTransform":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#transform

        **QTransform QPaintEngineState::transform() const**

        Returns the matrix in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyTransform**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def painter(self) -> "QPainter":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#painter

        **QPainter *QPaintEngineState::painter() const**

        Returns a pointer to the painter currently updating the paint engine.
        """
        ...

    def compositionMode(self) -> "QPainter.CompositionMode":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#compositionMode

        **QPainter::CompositionMode QPaintEngineState::compositionMode() const**

        Returns the composition mode in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyCompositionMode**
        flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def renderHints(self) -> "QPainter.RenderHint":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#renderHints

        **QPainter::RenderHints QPaintEngineState::renderHints() const**

        Returns the render hints in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyHints**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def isClipEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#isClipEnabled

        **bool QPaintEngineState::isClipEnabled() const**

        Returns whether clipping is enabled or not in the current paint engine
        state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyClipEnabled**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def clipPath(self) -> "QPainterPath":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#clipPath

        **QPainterPath QPaintEngineState::clipPath() const**

        Returns the clip path in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyClipPath**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def clipRegion(self) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#clipRegion

        **QRegion QPaintEngineState::clipRegion() const**

        Returns the clip region in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyClipRegion**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def clipOperation(self) -> QtCore.Qt.ClipOperation:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#clipOperation

        **Qt::ClipOperation QPaintEngineState::clipOperation() const**

        Returns the clip operation in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes either the **QPaintEngine::DirtyClipPath**
        or the **QPaintEngine::DirtyClipRegion**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def opacity(self) -> float:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#opacity

        **qreal QPaintEngineState::opacity() const**

        Returns the opacity in the current paint engine state.
        """
        ...

    def font(self) -> QFont:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#font

        **QFont QPaintEngineState::font() const**

        Returns the font in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyFont**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def backgroundMode(self) -> QtCore.Qt.BGMode:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#backgroundMode

        **Qt::BGMode QPaintEngineState::backgroundMode() const**

        Returns the background mode in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyBackgroundMode**
        flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def backgroundBrush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#backgroundBrush

        **QBrush QPaintEngineState::backgroundBrush() const**

        Returns the background brush in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyBackground**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def brushOrigin(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#brushOrigin

        **QPointF QPaintEngineState::brushOrigin() const**

        Returns the brush origin in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyBrushOrigin**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def brush(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#brush

        **QBrush QPaintEngineState::brush() const**

        Returns the brush in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyBrush**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def pen(self) -> "QPen":
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#pen

        **QPen QPaintEngineState::pen() const**

        Returns the pen in the current paint engine state.

        This variable should only be used when the **state** () returns a
        combination which includes the **QPaintEngine::DirtyPen**  flag.

        **See also** **state** () and **QPaintEngine::updateState** ().
        """
        ...

    def state(self) -> QPaintEngine.DirtyFlag:
        """
        https://doc.qt.io/qt-6/qpaintenginestate.html#state

        **QPaintEngine::DirtyFlags QPaintEngineState::state() const**

        Returns a combination of flags identifying the set of properties that
        need to be updated when updating the paint engine's state (i.e. during a
        call to the **QPaintEngine::updateState** () function).

        **See also** **QPaintEngine::updateState** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QItemSelection(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qitemselection.html

    **Detailed Description**

    A QItemSelection describes the items in a model that have been selected by
    the user. A QItemSelection is basically a list of selection ranges, see
    **QItemSelectionRange** . It provides functions for creating and
    manipulating selections, and selecting a range of items from a model.

    The QItemSelection class is one of the **Model/View Classes**  and is part
    of Qt's **model/view framework** .

    An item selection can be constructed and initialized to contain a range of
    items from an existing model. The following example constructs a selection
    that contains a range of items from the given `model`, beginning at the
    `topLeft`, and ending at the `bottomRight`.

    **QItemSelection**  *selection = new **QItemSelection** (topLeft,
    bottomRight);

    An empty item selection can be constructed, and later populated as required.
    So, if the model is going to be unavailable when we construct the item
    selection, we can rewrite the above code in the following way:

    **QItemSelection**  *selection = new **QItemSelection** ();
        ...
    selection->select(topLeft, bottomRight);

    QItemSelection saves memory, and avoids unnecessary work, by working with
    selection ranges rather than recording the model item index for each item in
    the selection. Generally, an instance of this class will contain a list of
    non-overlapping selection ranges.

    Use **merge** () to merge one item selection into another without making
    overlapping ranges. Use **split** () to split one selection range into
    smaller ranges based on a another selection range.

    **See also** **Model/View Programming**  and **QItemSelectionModel** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qitemselection.html#QItemSelection

        **QItemSelection::QItemSelection(const QModelIndex & topLeft , const
        QModelIndex & bottomRight )**

        Constructs an item selection that extends from the top-left model item,
        specified by the **topLeft** index, to the bottom-right item, specified
        by **bottomRight**.
        """
        ...

    @typing.overload
    def __init__(self, topLeft: QModelIndex, bottomRight: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qitemselection.html#QItemSelection-1

        **[default] QItemSelection::QItemSelection()**

        Constructs an empty selection.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QItemSelection") -> None:
        """
        https://doc.qt.io/qt-6/qitemselection.html#QItemSelection

        **QItemSelection::QItemSelection(const QModelIndex & topLeft , const
        QModelIndex & bottomRight )**

        Constructs an item selection that extends from the top-left model item,
        specified by the **topLeft** index, to the bottom-right item, specified
        by **bottomRight**.
        """
        ...

    def lastIndexOf(self, value: QItemSelectionRange, from_: int = ...) -> int:
        ...

    def indexOf(self, value: QItemSelectionRange, from_: int = ...) -> int:
        ...

    def last(self) -> QItemSelectionRange:
        ...

    def first(self) -> QItemSelectionRange:
        ...

    def __len__(self) -> int:
        ...

    @typing.overload
    def count(self, range: QItemSelectionRange) -> int:
        ...

    @typing.overload
    def count(self) -> int:
        ...

    def move(self, from_: int, to: int) -> None:
        ...

    def takeLast(self) -> QItemSelectionRange:
        ...

    def takeFirst(self) -> QItemSelectionRange:
        ...

    def takeAt(self, i: int) -> QItemSelectionRange:
        ...

    def removeAll(self, range: QItemSelectionRange) -> int:
        ...

    def removeAt(self, i: int) -> None:
        ...

    def replace(self, i: int, range: QItemSelectionRange) -> None:
        ...

    def insert(self, i: int, range: QItemSelectionRange) -> None:
        ...

    def prepend(self, range: QItemSelectionRange) -> None:
        ...

    def append(self, range: QItemSelectionRange) -> None:
        ...

    def isEmpty(self) -> bool:
        ...

    def clear(self) -> None:
        ...

    @typing.overload
    def __getitem__(self, i: int) -> QItemSelectionRange:
        ...

    @typing.overload
    def __getitem__(self, slice: slice) -> "QItemSelection":
        ...

    @typing.overload
    def __delitem__(self, i: int) -> None:
        ...

    @typing.overload
    def __delitem__(self, slice: slice) -> None:
        ...

    @typing.overload
    def __setitem__(self, i: int, range: QItemSelectionRange) -> None:
        ...

    @typing.overload
    def __setitem__(self, slice: slice, list: "QItemSelection") -> None:
        ...

    @staticmethod
    def split(
        range: QItemSelectionRange, other: QItemSelectionRange, result: "QItemSelection"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemselection.html#split

        **[static] void QItemSelection::split(const QItemSelectionRange & range
        , const QItemSelectionRange & other , QItemSelection * result )**

        Splits the selection **range** using the selection **other** range.
        Removes all items in **other** from **range** and puts the result in
        **result**. This can be compared with the semantics of the **subtract**
        operation of a set.

        **See also** **merge** ().
        """
        ...

    def merge(
        self, other: "QItemSelection", command: QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qitemselection.html#merge

        **void QItemSelection::merge(const QItemSelection & other ,
        QItemSelectionModel::SelectionFlags command )**

        Merges the **other** selection with this **QItemSelection**  using the
        **command** given. This method guarantees that no ranges are
        overlapping.

        Note that only **QItemSelectionModel::Select** ,
        **QItemSelectionModel::Deselect** , and **QItemSelectionModel::Toggle**
        are supported.

        **See also** **split** ().
        """
        ...

    def indexes(self) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qitemselection.html#indexes

        **QModelIndexList QItemSelection::indexes() const**

        Returns a list of model indexes that correspond to the selected items.
        """
        ...

    def __contains__(self, index: QModelIndex) -> int:
        ...

    def contains(self, index: QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qitemselection.html#contains

        **bool QItemSelection::contains(const QModelIndex & index ) const**

        Returns `true` if the selection contains the given **index** ; otherwise
        returns `false`.
        """
        ...

    def select(self, topLeft: QModelIndex, bottomRight: QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qitemselection.html#select

        **void QItemSelection::select(const QModelIndex & topLeft , const
        QModelIndex & bottomRight )**

        Adds the items in the range that extends from the top-left model item,
        specified by the **topLeft** index, to the bottom-right item, specified
        by **bottomRight** to the list.

        **Note:** **topLeft** and **bottomRight** must have the same parent.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtNetwork
from PyQt6 import QtCore


class QQmlNetworkAccessManagerFactory(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlnetworkaccessmanagerfactory.html

    **Detailed Description**

    A QML engine uses QNetworkAccessManager for all network access. By
    implementing a factory, it is possible to provide the QML engine with custom
    QNetworkAccessManager instances with specialized caching, proxy and cookies
    support.

    To implement a factory, subclass QQmlNetworkAccessManagerFactory and
    implement the virtual **create** () method, then assign it to the relevant
    QML engine using **QQmlEngine::setNetworkAccessManagerFactory** ().

    Note the QML engine may create QNetworkAccessManager instances from multiple
    threads. Because of this, the implementation of the **create** () method
    must be **reentrant** . In addition, the developer should be careful if the
    signals of the object to be returned from **create** () are connected to the
    slots of an object that may be created in a different thread:

    * The QML engine internally handles all requests, and cleans up any
    QNetworkReply objects it creates. Receiving the
    QNetworkAccessManager::finished() signal in another thread may not provide
    the receiver with a valid reply object if it has already been deleted.
      *
    Authentication details provided to
    QNetworkAccessManager::authenticationRequired() must be provided
    immediately, so this signal cannot be connected as a
    **Qt::QueuedConnection**  (or as the default **Qt::AutoConnection**  from
    another thread).

    For more information about signals and threads, see **Threads and QObjects**
    and **Signals and Slots Across Threads** .

    **See also** **Network Access Manager Factory Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QQmlNetworkAccessManagerFactory") -> None:
        ...

    def create(self, parent: QtCore.QObject) -> QtNetwork.QNetworkAccessManager:
        """
        https://doc.qt.io/qt-6/qqmlnetworkaccessmanagerfactory.html#create

        **[pure virtual] QNetworkAccessManager
        *QQmlNetworkAccessManagerFactory::create(QObject * parent )**

        Creates and returns a network access manager with the specified
        **parent**. This method must return a new QNetworkAccessManager instance
        each time it is called.

        Note: this method may be called by multiple threads, so ensure the
        implementation of this method is reentrant.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6.QtPrintSupport import *


class QPageSetupDialog(QtWidgets.QDialog):
    """
    https://doc.qt.io/qt-6/qpagesetupdialog.html

    **Detailed Description**

    On Windows and macOS the page setup dialog is implemented using the native
    page setup dialogs.

    Note that on Windows and macOS custom paper sizes won't be reflected in the
    native page setup dialogs. Additionally, custom page margins set on a
    **QPrinter**  won't show in the native macOS page setup dialog.

    **See also** **QPrinter**  and **QPrintDialog** .
    """

    @typing.overload
    def __init__(
        self, printer: "QPrinter", parent: typing.Optional[QtWidgets.QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#QPageSetupDialog

        **QPageSetupDialog::QPageSetupDialog(QPrinter * printer , QWidget *
        parent = nullptr)**

        Constructs a page setup dialog that configures **printer** with
        **parent** as the parent widget.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#QPageSetupDialog-1

        **QPageSetupDialog::QPageSetupDialog(QWidget * parent = nullptr)**

        Constructs a page setup dialog that configures a default-constructed
        **QPrinter**  with **parent** as the parent widget.

        **See also** **printer** ().
        """
        ...

    def printer(self) -> "QPrinter":
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#printer

        **QPrinter *QPageSetupDialog::printer()**

        Returns the printer that was passed to the **QPageSetupDialog**
        constructor.
        """
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#done

        **[override virtual] void QPageSetupDialog::done(int result )**

        Reimplements: **QDialog::done** (int r).
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#open

        **void QPageSetupDialog::open(QObject * receiver , const char * member
        )**

        This is an overloaded function.

        Opens the dialog and connects its **accepted** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#open

        **void QPageSetupDialog::open(QObject * receiver , const char * member
        )**

        This is an overloaded function.

        Opens the dialog and connects its **accepted** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def exec(self) -> int:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#exec

        **[override virtual] int QPageSetupDialog::exec()**

        Reimplements: **QDialog::exec** ().

        This virtual function is called to pop up the dialog. It must be
        reimplemented in subclasses.
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qpagesetupdialog.html#setVisible

        **[override virtual] void QPageSetupDialog::setVisible(bool visible )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...
